==> nextcloud-25.0.4.tgz: nextcloud/apps/viewer/l10n/es.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Sencillo visor de archivos con presentación para archivos de medios",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "¡Muestra tus últimas fotos y vídeos de vacaciones como en las películas, ofrece un vistazo a tu última novela directamente desde tu Nextcloud, escoge el mejor GIF de tu colección gracias a la previsualización directa de tus archivos favoritos y mucho más!",
    "Your browser does not support audio." : "Tu navegador no soporta audio.",
    "Error loading {name}" : "Error al cargar {name}",
    "Image saved" : "Imagen guardada",
    "Error saving image" : "Error guardando imágen",
    "Unsaved changes" : "Cambios sin guardar",
    "Drop changes" : "Descartar cambios",
    "Content of \"{fileName}\"" : "Contenido de \"{fileName}\"",
    "Your browser does not support videos." : "Tu navegador no soporta videos.",
    "Edit" : "Editar",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Descarga",
    "Delete" : "Eliminar",
    "There is no plugin available to display this file type" : "No hay plugin disponible para mostrar este tipo de archivo",
    "View" : "Ver",
    "Name" : "Nombre",
    "Save" : "Guardar",
    "Save as" : "Guardar como",
    "Back" : "Atrás",
    "Loading …" : "Cargando …",
    "Reset" : "Restablecer",
    "All changes will be lost." : "Todos los cambios se perderán.",
    "Are you sure you want to continue?" : "¿Está seguro que desea continuar?",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Deshacer",
    "Redo" : "Rehacer",
    "Show original image" : "Mostrar mensaje original",
    "Zoom in" : "Acercar",
    "Zoom out" : "Alejar",
    "Toggle zoom menu" : "Conmutar menú de zoom",
    "Adjust" : "Ajustar",
    "Fine-tune" : "Entonar",
    "Filters" : "Filtros",
    "Watermark" : "Marca de agua",
    "Draw" : "Dibujar",
    "Resize" : "Redimensionar",
    "Invalid image." : "Imágen inválida",
    "Error while uploading the image." : "Se encontró un error al cargar la imagen.",
    "are not images" : "no son imágenes",
    "is not an image" : "no es una imágen",
    "to be uploaded" : "a cargar",
    "Crop" : "Recortar",
    "Original" : "Original",
    "Custom" : "Personalizado",
    "Square" : "Cuadrado",
    "Landscape" : "Paisaje",
    "Portrait" : "Portarretrato",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clásica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Difuminar",
    "Brightness" : "Brillo",
    "Contrast" : "Contraste",
    "Un-flip X" : "Revertir voltear X",
    "Flip X" : "Voltear X",
    "Un-flip Y" : "Revertir voltear Y",
    "Flip Y" : "Voltear Y",
    "HSV" : "HSV",
    "Hue" : "Tone",
    "Saturation" : "Saturación",
    "Value" : "Valor",
    "Image" : "Imagen",
    "Importing …" : "Importando ...",
    "+ Add image" : "+ Añadir imágen",
    "Line" : "Línea",
    "Pen" : "Pluma",
    "Polygon" : "Polígono",
    "Sides" : "Lados",
    "Rectangle" : "Rectángulo",
    "Corner Radius" : "Radio de esquina",
    "Width in pixels" : "Ancho en píxeles",
    "Height in pixels" : "Altura en píxeles",
    "Toggle ratio lock" : "Conmutar bloqueo de proporción",
    "Reset to original image size" : "Reajustar a tamaño original de la imágen",
    "Rotate" : "Rotar",
    "Text" : "Texto",
    "Text spacing" : "Espacio del texto",
    "Text alignment" : "Alineación del texto",
    "Font family" : "Familia de fuente",
    "Size" : "Tamaño",
    "Letter spacing" : "Espacio entre letras",
    "Line height" : "Altura de línea",
    "Warmth" : "Calidez",
    "+ Add watermark" : "+ Añadir marca de agua",
    "Choose watermark type" : "Seleccione el tipo de marca de agua",
    "Upload watermark" : "Cargar marca de agua",
    "Add as text" : "Añadir como texto",
    "Padding" : "Desplazamiento",
    "Shadow" : "Sombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidad",
    "Position" : "Posición",
    "Stroke" : "Trazo",
    "Save image as" : "Guardar imagen como",
    "Extension" : "Extensión",
    "Name is required." : "Se requiere Nombre.",
    "Quality" : "Calidad",
    "Saved image size (width x height)" : "Tamaño de la imagen guardada (anchura x altura)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Tenga en cuenta que el área a recortar es menor al redimensionamiento aplicado lo que puede causar pérdida de calidad",
    "Actual size (100%)" : "Tamaño actual (100%)",
    "Fit size" : "Ajustar tamaño",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Muestra tus últimas fotos y vídeos de vacaciones como en las películas, ofrece un vistazo a tu última novela directamente desde tu Nextcloud, escoge el mejor GIF de tu colección gracias a la previsualización directa de tus archivos favoritos y mucho más."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-25.0.7.tgz: nextcloud/apps/viewer/l10n/es.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Sencillo visor de archivos con presentación para archivos de medios",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "¡Muestra tus últimas fotos y vídeos de vacaciones como en las películas, ofrece un vistazo a tu última novela directamente desde tu Nextcloud, escoge el mejor GIF de tu colección gracias a la previsualización directa de tus archivos favoritos y mucho más!",
    "Your browser does not support audio." : "Tu navegador no soporta audio.",
    "Error loading {name}" : "Error al cargar {name}",
    "Image saved" : "Imagen guardada",
    "Error saving image" : "Error guardando imágen",
    "Unsaved changes" : "Cambios sin guardar",
    "Drop changes" : "Descartar cambios",
    "\"{fileName}\"" : "\"{fileName}\"",
    "Your browser does not support videos." : "Tu navegador no soporta videos.",
    "Edit" : "Editar",
    "Exit full screen" : "Salir de pantalla completa",
    "Full screen" : "Pantalla completa",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Descarga",
    "Delete" : "Eliminar",
    "This file no longer exists" : "Este archivo ya no existe",
    "There is no plugin available to display this file type" : "No hay plugin disponible para mostrar este tipo de archivo",
    "View" : "Ver",
    "Name" : "Nombre",
    "Save" : "Guardar",
    "Save as" : "Guardar como",
    "Back" : "Atrás",
    "Loading …" : "Cargando …",
    "Reset" : "Restablecer",
    "All changes will be lost." : "Todos los cambios se perderán.",
    "Are you sure you want to continue?" : "¿Está seguro que desea continuar?",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Deshacer",
    "Redo" : "Rehacer",
    "Show original image" : "Mostrar mensaje original",
    "Zoom in" : "Acercar",
    "Zoom out" : "Alejar",
    "Toggle zoom menu" : "Conmutar menú de zoom",
    "Adjust" : "Ajustar",
    "Fine-tune" : "Entonar",
    "Filters" : "Filtros",
    "Watermark" : "Marca de agua",
    "Draw" : "Dibujar",
    "Resize" : "Redimensionar",
    "Invalid image." : "Imágen inválida",
    "Error while uploading the image." : "Se encontró un error al cargar la imagen.",
    "are not images" : "no son imágenes",
    "is not an image" : "no es una imágen",
    "to be uploaded" : "a cargar",
    "Crop" : "Recortar",
    "Original" : "Original",
    "Custom" : "Personalizado",
    "Square" : "Cuadrado",
    "Landscape" : "Paisaje",
    "Portrait" : "Portarretrato",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clásica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Difuminar",
    "Brightness" : "Brillo",
    "Contrast" : "Contraste",
    "Un-flip X" : "Revertir voltear X",
    "Flip X" : "Voltear X",
    "Un-flip Y" : "Revertir voltear Y",
    "Flip Y" : "Voltear Y",
    "HSV" : "HSV",
    "Hue" : "Tone",
    "Saturation" : "Saturación",
    "Value" : "Valor",
    "Image" : "Imagen",
    "Importing …" : "Importando ...",
    "+ Add image" : "+ Añadir imágen",
    "Line" : "Línea",
    "Pen" : "Pluma",
    "Polygon" : "Polígono",
    "Sides" : "Lados",
    "Rectangle" : "Rectángulo",
    "Corner Radius" : "Radio de esquina",
    "Width in pixels" : "Ancho en píxeles",
    "Height in pixels" : "Altura en píxeles",
    "Toggle ratio lock" : "Conmutar bloqueo de proporción",
    "Reset to original image size" : "Reajustar a tamaño original de la imágen",
    "Rotate" : "Rotar",
    "Text" : "Texto",
    "Text spacing" : "Espacio del texto",
    "Text alignment" : "Alineación del texto",
    "Font family" : "Familia de fuente",
    "Size" : "Tamaño",
    "Letter spacing" : "Espacio entre letras",
    "Line height" : "Altura de línea",
    "Warmth" : "Calidez",
    "+ Add watermark" : "+ Añadir marca de agua",
    "Choose watermark type" : "Seleccione el tipo de marca de agua",
    "Upload watermark" : "Cargar marca de agua",
    "Add as text" : "Añadir como texto",
    "Padding" : "Desplazamiento",
    "Shadow" : "Sombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidad",
    "Position" : "Posición",
    "Stroke" : "Trazo",
    "Save image as" : "Guardar imagen como",
    "Extension" : "Extensión",
    "Name is required." : "Se requiere Nombre.",
    "Quality" : "Calidad",
    "Saved image size (width x height)" : "Tamaño de la imagen guardada (anchura x altura)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Tenga en cuenta que el área a recortar es menor al redimensionamiento aplicado lo que puede causar pérdida de calidad",
    "Actual size (100%)" : "Tamaño actual (100%)",
    "Fit size" : "Ajustar tamaño",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Muestra tus últimas fotos y vídeos de vacaciones como en las películas, ofrece un vistazo a tu última novela directamente desde tu Nextcloud, escoge el mejor GIF de tu colección gracias a la previsualización directa de tus archivos favoritos y mucho más."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
